# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetFailoverGroupResult',
    'AwaitableGetFailoverGroupResult',
    'get_failover_group',
    'get_failover_group_output',
]

@pulumi.output_type
class GetFailoverGroupResult:
    """
    A collection of values returned by getFailoverGroup.
    """
    def __init__(__self__, databases=None, id=None, name=None, partner_servers=None, read_write_endpoint_failover_policies=None, readonly_endpoint_failover_policy_enabled=None, server_id=None, tags=None):
        if databases and not isinstance(databases, list):
            raise TypeError("Expected argument 'databases' to be a list")
        pulumi.set(__self__, "databases", databases)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if partner_servers and not isinstance(partner_servers, list):
            raise TypeError("Expected argument 'partner_servers' to be a list")
        pulumi.set(__self__, "partner_servers", partner_servers)
        if read_write_endpoint_failover_policies and not isinstance(read_write_endpoint_failover_policies, list):
            raise TypeError("Expected argument 'read_write_endpoint_failover_policies' to be a list")
        pulumi.set(__self__, "read_write_endpoint_failover_policies", read_write_endpoint_failover_policies)
        if readonly_endpoint_failover_policy_enabled and not isinstance(readonly_endpoint_failover_policy_enabled, bool):
            raise TypeError("Expected argument 'readonly_endpoint_failover_policy_enabled' to be a bool")
        pulumi.set(__self__, "readonly_endpoint_failover_policy_enabled", readonly_endpoint_failover_policy_enabled)
        if server_id and not isinstance(server_id, str):
            raise TypeError("Expected argument 'server_id' to be a str")
        pulumi.set(__self__, "server_id", server_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def databases(self) -> Sequence[_builtins.str]:
        """
        A set of database names in the Failover Group.
        """
        return pulumi.get(self, "databases")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="partnerServers")
    def partner_servers(self) -> Sequence['outputs.GetFailoverGroupPartnerServerResult']:
        """
        A `partner_server` block as defined below.
        """
        return pulumi.get(self, "partner_servers")

    @_builtins.property
    @pulumi.getter(name="readWriteEndpointFailoverPolicies")
    def read_write_endpoint_failover_policies(self) -> Sequence['outputs.GetFailoverGroupReadWriteEndpointFailoverPolicyResult']:
        """
        A `read_write_endpoint_failover_policy` block as defined below.
        """
        return pulumi.get(self, "read_write_endpoint_failover_policies")

    @_builtins.property
    @pulumi.getter(name="readonlyEndpointFailoverPolicyEnabled")
    def readonly_endpoint_failover_policy_enabled(self) -> _builtins.bool:
        """
        Whether failover is enabled for the readonly endpoint.
        """
        return pulumi.get(self, "readonly_endpoint_failover_policy_enabled")

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> _builtins.str:
        return pulumi.get(self, "server_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        """
        A mapping of tags which are assigned to the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetFailoverGroupResult(GetFailoverGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFailoverGroupResult(
            databases=self.databases,
            id=self.id,
            name=self.name,
            partner_servers=self.partner_servers,
            read_write_endpoint_failover_policies=self.read_write_endpoint_failover_policies,
            readonly_endpoint_failover_policy_enabled=self.readonly_endpoint_failover_policy_enabled,
            server_id=self.server_id,
            tags=self.tags)


def get_failover_group(name: Optional[_builtins.str] = None,
                       server_id: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFailoverGroupResult:
    """
    Use this data source to access information about an existing Microsoft Azure SQL Failover Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.mssql.get_failover_group(name="example",
        server_id="example-sql-server")
    pulumi.export("mssqlFailoverGroupId", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Sql` - 2023-08-01-preview


    :param _builtins.str name: The name of the Failover Group.
    :param _builtins.str server_id: The ID of the primary SQL Server where the Failover Group exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['serverId'] = server_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:mssql/getFailoverGroup:getFailoverGroup', __args__, opts=opts, typ=GetFailoverGroupResult).value

    return AwaitableGetFailoverGroupResult(
        databases=pulumi.get(__ret__, 'databases'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        partner_servers=pulumi.get(__ret__, 'partner_servers'),
        read_write_endpoint_failover_policies=pulumi.get(__ret__, 'read_write_endpoint_failover_policies'),
        readonly_endpoint_failover_policy_enabled=pulumi.get(__ret__, 'readonly_endpoint_failover_policy_enabled'),
        server_id=pulumi.get(__ret__, 'server_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_failover_group_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                              server_id: Optional[pulumi.Input[_builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFailoverGroupResult]:
    """
    Use this data source to access information about an existing Microsoft Azure SQL Failover Group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.mssql.get_failover_group(name="example",
        server_id="example-sql-server")
    pulumi.export("mssqlFailoverGroupId", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Sql` - 2023-08-01-preview


    :param _builtins.str name: The name of the Failover Group.
    :param _builtins.str server_id: The ID of the primary SQL Server where the Failover Group exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['serverId'] = server_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:mssql/getFailoverGroup:getFailoverGroup', __args__, opts=opts, typ=GetFailoverGroupResult)
    return __ret__.apply(lambda __response__: GetFailoverGroupResult(
        databases=pulumi.get(__response__, 'databases'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        partner_servers=pulumi.get(__response__, 'partner_servers'),
        read_write_endpoint_failover_policies=pulumi.get(__response__, 'read_write_endpoint_failover_policies'),
        readonly_endpoint_failover_policy_enabled=pulumi.get(__response__, 'readonly_endpoint_failover_policy_enabled'),
        server_id=pulumi.get(__response__, 'server_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ManagedRedisCustomerManagedKey',
    'ManagedRedisDefaultDatabase',
    'ManagedRedisDefaultDatabaseModule',
    'ManagedRedisIdentity',
    'GetCustomerManagedKeyResult',
    'GetDefaultDatabaseResult',
    'GetDefaultDatabaseModuleResult',
    'GetIdentityResult',
]

@pulumi.output_type
class ManagedRedisCustomerManagedKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "keyVaultKeyId":
            suggest = "key_vault_key_id"
        elif key == "userAssignedIdentityId":
            suggest = "user_assigned_identity_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ManagedRedisCustomerManagedKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ManagedRedisCustomerManagedKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ManagedRedisCustomerManagedKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 key_vault_key_id: _builtins.str,
                 user_assigned_identity_id: _builtins.str):
        """
        :param _builtins.str key_vault_key_id: The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name/a1b2c3d4`.
        :param _builtins.str user_assigned_identity_id: The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        pulumi.set(__self__, "key_vault_key_id", key_vault_key_id)
        pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @_builtins.property
    @pulumi.getter(name="keyVaultKeyId")
    def key_vault_key_id(self) -> _builtins.str:
        """
        The ID of the key vault key used for encryption. For example: `https://example-vault-name.vault.azure.net/keys/example-key-name/a1b2c3d4`.
        """
        return pulumi.get(self, "key_vault_key_id")

    @_builtins.property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> _builtins.str:
        """
        The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        return pulumi.get(self, "user_assigned_identity_id")


@pulumi.output_type
class ManagedRedisDefaultDatabase(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessKeysAuthenticationEnabled":
            suggest = "access_keys_authentication_enabled"
        elif key == "clientProtocol":
            suggest = "client_protocol"
        elif key == "clusteringPolicy":
            suggest = "clustering_policy"
        elif key == "evictionPolicy":
            suggest = "eviction_policy"
        elif key == "geoReplicationGroupName":
            suggest = "geo_replication_group_name"
        elif key == "persistenceAppendOnlyFileBackupFrequency":
            suggest = "persistence_append_only_file_backup_frequency"
        elif key == "persistenceRedisDatabaseBackupFrequency":
            suggest = "persistence_redis_database_backup_frequency"
        elif key == "primaryAccessKey":
            suggest = "primary_access_key"
        elif key == "secondaryAccessKey":
            suggest = "secondary_access_key"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ManagedRedisDefaultDatabase. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ManagedRedisDefaultDatabase.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ManagedRedisDefaultDatabase.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_keys_authentication_enabled: Optional[_builtins.bool] = None,
                 client_protocol: Optional[_builtins.str] = None,
                 clustering_policy: Optional[_builtins.str] = None,
                 eviction_policy: Optional[_builtins.str] = None,
                 geo_replication_group_name: Optional[_builtins.str] = None,
                 id: Optional[_builtins.str] = None,
                 modules: Optional[Sequence['outputs.ManagedRedisDefaultDatabaseModule']] = None,
                 persistence_append_only_file_backup_frequency: Optional[_builtins.str] = None,
                 persistence_redis_database_backup_frequency: Optional[_builtins.str] = None,
                 port: Optional[_builtins.int] = None,
                 primary_access_key: Optional[_builtins.str] = None,
                 secondary_access_key: Optional[_builtins.str] = None):
        """
        :param _builtins.bool access_keys_authentication_enabled: Whether access key authentication is enabled for the database. Defaults to `false`.
        :param _builtins.str client_protocol: Specifies whether redis clients can connect using TLS-encrypted or plaintext redis protocols. Possible values are `Encrypted` and `Plaintext`. Defaults to `Encrypted`.
        :param _builtins.str clustering_policy: Clustering policy specified at create time. Possible values are `EnterpriseCluster`, `OSSCluster` and `NoCluster`. Defaults to `OSSCluster`.
               
               !> **Note:** Changing `clustering_policy` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        :param _builtins.str eviction_policy: Specifies the Redis eviction policy. Possible values are `AllKeysLFU`, `AllKeysLRU`, `AllKeysRandom`, `VolatileLRU`, `VolatileLFU`, `VolatileTTL`, `VolatileRandom` and `NoEviction`. Defaults to `VolatileLRU`.
        :param _builtins.str geo_replication_group_name: The name of the geo-replication group. If provided, a geo-replication group will be created for this database with itself as the only member. Use `azurerm_managed_redis_database_geo_replication` resource to manage group membership, linking and unlinking. All databases to be linked have to have the same group name. Refer to the [Managed Redis geo-replication documentation](https://learn.microsoft.com/azure/redis/how-to-active-geo-replication) for more information.
               
               !> **Note:** Changing `geo_replication_group_name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        :param _builtins.str id: The ID of the Managed Redis Database Instance.
        :param Sequence['ManagedRedisDefaultDatabaseModuleArgs'] modules: A `module` block as defined below. Refer to [the modules documentation](https://learn.microsoft.com/azure/redis/redis-modules) to learn more.
        :param _builtins.str persistence_append_only_file_backup_frequency: The frequency of Append Only File (AOF) backups. The only possible value is `1s`. Providing this value implies AOF persistence method is enabled. Conflicts with `persistence_redis_database_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
        :param _builtins.str persistence_redis_database_backup_frequency: The frequency of Redis Database (RDB) backups. Possible values are `1h`, `6h` and `12h`. Providing this value implies RDB persistence method is enabled. Conflicts with `persistence_append_only_file_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
        :param _builtins.int port: TCP port of the database endpoint.
        :param _builtins.str primary_access_key: The Primary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
        :param _builtins.str secondary_access_key: The Secondary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
        """
        if access_keys_authentication_enabled is not None:
            pulumi.set(__self__, "access_keys_authentication_enabled", access_keys_authentication_enabled)
        if client_protocol is not None:
            pulumi.set(__self__, "client_protocol", client_protocol)
        if clustering_policy is not None:
            pulumi.set(__self__, "clustering_policy", clustering_policy)
        if eviction_policy is not None:
            pulumi.set(__self__, "eviction_policy", eviction_policy)
        if geo_replication_group_name is not None:
            pulumi.set(__self__, "geo_replication_group_name", geo_replication_group_name)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if modules is not None:
            pulumi.set(__self__, "modules", modules)
        if persistence_append_only_file_backup_frequency is not None:
            pulumi.set(__self__, "persistence_append_only_file_backup_frequency", persistence_append_only_file_backup_frequency)
        if persistence_redis_database_backup_frequency is not None:
            pulumi.set(__self__, "persistence_redis_database_backup_frequency", persistence_redis_database_backup_frequency)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if primary_access_key is not None:
            pulumi.set(__self__, "primary_access_key", primary_access_key)
        if secondary_access_key is not None:
            pulumi.set(__self__, "secondary_access_key", secondary_access_key)

    @_builtins.property
    @pulumi.getter(name="accessKeysAuthenticationEnabled")
    def access_keys_authentication_enabled(self) -> Optional[_builtins.bool]:
        """
        Whether access key authentication is enabled for the database. Defaults to `false`.
        """
        return pulumi.get(self, "access_keys_authentication_enabled")

    @_builtins.property
    @pulumi.getter(name="clientProtocol")
    def client_protocol(self) -> Optional[_builtins.str]:
        """
        Specifies whether redis clients can connect using TLS-encrypted or plaintext redis protocols. Possible values are `Encrypted` and `Plaintext`. Defaults to `Encrypted`.
        """
        return pulumi.get(self, "client_protocol")

    @_builtins.property
    @pulumi.getter(name="clusteringPolicy")
    def clustering_policy(self) -> Optional[_builtins.str]:
        """
        Clustering policy specified at create time. Possible values are `EnterpriseCluster`, `OSSCluster` and `NoCluster`. Defaults to `OSSCluster`.

        !> **Note:** Changing `clustering_policy` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        """
        return pulumi.get(self, "clustering_policy")

    @_builtins.property
    @pulumi.getter(name="evictionPolicy")
    def eviction_policy(self) -> Optional[_builtins.str]:
        """
        Specifies the Redis eviction policy. Possible values are `AllKeysLFU`, `AllKeysLRU`, `AllKeysRandom`, `VolatileLRU`, `VolatileLFU`, `VolatileTTL`, `VolatileRandom` and `NoEviction`. Defaults to `VolatileLRU`.
        """
        return pulumi.get(self, "eviction_policy")

    @_builtins.property
    @pulumi.getter(name="geoReplicationGroupName")
    def geo_replication_group_name(self) -> Optional[_builtins.str]:
        """
        The name of the geo-replication group. If provided, a geo-replication group will be created for this database with itself as the only member. Use `azurerm_managed_redis_database_geo_replication` resource to manage group membership, linking and unlinking. All databases to be linked have to have the same group name. Refer to the [Managed Redis geo-replication documentation](https://learn.microsoft.com/azure/redis/how-to-active-geo-replication) for more information.

        !> **Note:** Changing `geo_replication_group_name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        """
        return pulumi.get(self, "geo_replication_group_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the Managed Redis Database Instance.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def modules(self) -> Optional[Sequence['outputs.ManagedRedisDefaultDatabaseModule']]:
        """
        A `module` block as defined below. Refer to [the modules documentation](https://learn.microsoft.com/azure/redis/redis-modules) to learn more.
        """
        return pulumi.get(self, "modules")

    @_builtins.property
    @pulumi.getter(name="persistenceAppendOnlyFileBackupFrequency")
    def persistence_append_only_file_backup_frequency(self) -> Optional[_builtins.str]:
        """
        The frequency of Append Only File (AOF) backups. The only possible value is `1s`. Providing this value implies AOF persistence method is enabled. Conflicts with `persistence_redis_database_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
        """
        return pulumi.get(self, "persistence_append_only_file_backup_frequency")

    @_builtins.property
    @pulumi.getter(name="persistenceRedisDatabaseBackupFrequency")
    def persistence_redis_database_backup_frequency(self) -> Optional[_builtins.str]:
        """
        The frequency of Redis Database (RDB) backups. Possible values are `1h`, `6h` and `12h`. Providing this value implies RDB persistence method is enabled. Conflicts with `persistence_append_only_file_backup_frequency`, only one persistence method is allowed. Conflicts with `geo_replication_group_name`, persistence can only be enabled on non-geo-replicated databases. Refer to [the persistence documentation](https://learn.microsoft.com/azure/redis/how-to-persistence) to learn more.
        """
        return pulumi.get(self, "persistence_redis_database_backup_frequency")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        TCP port of the database endpoint.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="primaryAccessKey")
    def primary_access_key(self) -> Optional[_builtins.str]:
        """
        The Primary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
        """
        return pulumi.get(self, "primary_access_key")

    @_builtins.property
    @pulumi.getter(name="secondaryAccessKey")
    def secondary_access_key(self) -> Optional[_builtins.str]:
        """
        The Secondary Access Key for the Managed Redis Database Instance. Only exported if `access_keys_authentication_enabled` is set to `true`.
        """
        return pulumi.get(self, "secondary_access_key")


@pulumi.output_type
class ManagedRedisDefaultDatabaseModule(dict):
    def __init__(__self__, *,
                 name: _builtins.str,
                 args: Optional[_builtins.str] = None,
                 version: Optional[_builtins.str] = None):
        """
        :param _builtins.str name: The name which should be used for this module. Possible values are `RedisBloom`, `RedisTimeSeries`, `RediSearch` and `RedisJSON`.
               
               !> **Note:** Changing `name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        :param _builtins.str args: Configuration options for the module (e.g. `ERROR_RATE 0.00 INITIAL_SIZE 400`).
               
               !> **Note:** Changing `args` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
               
               > **Note:** Only `RediSearch` and `RedisJSON` modules are allowed with geo-replication.
        :param _builtins.str version: Version of the module to be used.
        """
        pulumi.set(__self__, "name", name)
        if args is not None:
            pulumi.set(__self__, "args", args)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name which should be used for this module. Possible values are `RedisBloom`, `RedisTimeSeries`, `RediSearch` and `RedisJSON`.

        !> **Note:** Changing `name` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def args(self) -> Optional[_builtins.str]:
        """
        Configuration options for the module (e.g. `ERROR_RATE 0.00 INITIAL_SIZE 400`).

        !> **Note:** Changing `args` forces database recreation. Data will be lost and Managed Redis will be unavailable during the operation.

        > **Note:** Only `RediSearch` and `RedisJSON` modules are allowed with geo-replication.
        """
        return pulumi.get(self, "args")

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[_builtins.str]:
        """
        Version of the module to be used.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class ManagedRedisIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ManagedRedisIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ManagedRedisIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ManagedRedisIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: _builtins.str,
                 identity_ids: Optional[Sequence[_builtins.str]] = None,
                 principal_id: Optional[_builtins.str] = None,
                 tenant_id: Optional[_builtins.str] = None):
        """
        :param _builtins.str type: Specifies the type of Managed Service Identity that should be configured on this Managed Redis instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        :param Sequence[_builtins.str] identity_ids: Specifies a list of User Assigned Managed Identity IDs to be assigned to this Managed Redis instance.
               
               > **Note:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        pulumi.set(__self__, "type", type)
        if identity_ids is not None:
            pulumi.set(__self__, "identity_ids", identity_ids)
        if principal_id is not None:
            pulumi.set(__self__, "principal_id", principal_id)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Managed Redis instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[_builtins.str]]:
        """
        Specifies a list of User Assigned Managed Identity IDs to be assigned to this Managed Redis instance.

        > **Note:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "principal_id")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class GetCustomerManagedKeyResult(dict):
    def __init__(__self__, *,
                 key_vault_key_id: _builtins.str,
                 user_assigned_identity_id: _builtins.str):
        """
        :param _builtins.str key_vault_key_id: The ID of the key vault key used for encryption.
        :param _builtins.str user_assigned_identity_id: The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        pulumi.set(__self__, "key_vault_key_id", key_vault_key_id)
        pulumi.set(__self__, "user_assigned_identity_id", user_assigned_identity_id)

    @_builtins.property
    @pulumi.getter(name="keyVaultKeyId")
    def key_vault_key_id(self) -> _builtins.str:
        """
        The ID of the key vault key used for encryption.
        """
        return pulumi.get(self, "key_vault_key_id")

    @_builtins.property
    @pulumi.getter(name="userAssignedIdentityId")
    def user_assigned_identity_id(self) -> _builtins.str:
        """
        The ID of the User Assigned Identity that has access to the Key Vault Key.
        """
        return pulumi.get(self, "user_assigned_identity_id")


@pulumi.output_type
class GetDefaultDatabaseResult(dict):
    def __init__(__self__, *,
                 access_keys_authentication_enabled: _builtins.bool,
                 client_protocol: _builtins.str,
                 clustering_policy: _builtins.str,
                 eviction_policy: _builtins.str,
                 geo_replication_group_name: _builtins.str,
                 geo_replication_linked_database_ids: Sequence[_builtins.str],
                 id: _builtins.str,
                 modules: Sequence['outputs.GetDefaultDatabaseModuleResult'],
                 persistence_append_only_file_backup_frequency: _builtins.str,
                 persistence_redis_database_backup_frequency: _builtins.str,
                 port: _builtins.int,
                 primary_access_key: _builtins.str,
                 secondary_access_key: _builtins.str):
        """
        :param _builtins.bool access_keys_authentication_enabled: Whether access key authentication is enabled for the database.
        :param _builtins.str client_protocol: The client protocol used by the database (either `Encrypted` or `Plaintext`).
        :param _builtins.str clustering_policy: The clustering policy used by the database.
        :param _builtins.str eviction_policy: The Redis eviction policy used by the database.
        :param _builtins.str geo_replication_group_name: The name of the geo-replication group.
        :param Sequence[_builtins.str] geo_replication_linked_database_ids: A list of linked database IDs for geo-replication.
        :param _builtins.str id: The ID of the Managed Redis Database Instance.
        :param Sequence['GetDefaultDatabaseModuleArgs'] modules: A list of `module` blocks as defined below.
        :param _builtins.str persistence_append_only_file_backup_frequency: The frequency of Append Only File (AOF) backups.
        :param _builtins.str persistence_redis_database_backup_frequency: The frequency of Redis Database (RDB) backups.
        :param _builtins.int port: The TCP port of the database endpoint.
        :param _builtins.str primary_access_key: The Primary Access Key for the Managed Redis Database instance.
        :param _builtins.str secondary_access_key: The Secondary Access Key for the Managed Redis Database instance.
        """
        pulumi.set(__self__, "access_keys_authentication_enabled", access_keys_authentication_enabled)
        pulumi.set(__self__, "client_protocol", client_protocol)
        pulumi.set(__self__, "clustering_policy", clustering_policy)
        pulumi.set(__self__, "eviction_policy", eviction_policy)
        pulumi.set(__self__, "geo_replication_group_name", geo_replication_group_name)
        pulumi.set(__self__, "geo_replication_linked_database_ids", geo_replication_linked_database_ids)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "modules", modules)
        pulumi.set(__self__, "persistence_append_only_file_backup_frequency", persistence_append_only_file_backup_frequency)
        pulumi.set(__self__, "persistence_redis_database_backup_frequency", persistence_redis_database_backup_frequency)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "primary_access_key", primary_access_key)
        pulumi.set(__self__, "secondary_access_key", secondary_access_key)

    @_builtins.property
    @pulumi.getter(name="accessKeysAuthenticationEnabled")
    def access_keys_authentication_enabled(self) -> _builtins.bool:
        """
        Whether access key authentication is enabled for the database.
        """
        return pulumi.get(self, "access_keys_authentication_enabled")

    @_builtins.property
    @pulumi.getter(name="clientProtocol")
    def client_protocol(self) -> _builtins.str:
        """
        The client protocol used by the database (either `Encrypted` or `Plaintext`).
        """
        return pulumi.get(self, "client_protocol")

    @_builtins.property
    @pulumi.getter(name="clusteringPolicy")
    def clustering_policy(self) -> _builtins.str:
        """
        The clustering policy used by the database.
        """
        return pulumi.get(self, "clustering_policy")

    @_builtins.property
    @pulumi.getter(name="evictionPolicy")
    def eviction_policy(self) -> _builtins.str:
        """
        The Redis eviction policy used by the database.
        """
        return pulumi.get(self, "eviction_policy")

    @_builtins.property
    @pulumi.getter(name="geoReplicationGroupName")
    def geo_replication_group_name(self) -> _builtins.str:
        """
        The name of the geo-replication group.
        """
        return pulumi.get(self, "geo_replication_group_name")

    @_builtins.property
    @pulumi.getter(name="geoReplicationLinkedDatabaseIds")
    def geo_replication_linked_database_ids(self) -> Sequence[_builtins.str]:
        """
        A list of linked database IDs for geo-replication.
        """
        return pulumi.get(self, "geo_replication_linked_database_ids")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the Managed Redis Database Instance.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def modules(self) -> Sequence['outputs.GetDefaultDatabaseModuleResult']:
        """
        A list of `module` blocks as defined below.
        """
        return pulumi.get(self, "modules")

    @_builtins.property
    @pulumi.getter(name="persistenceAppendOnlyFileBackupFrequency")
    def persistence_append_only_file_backup_frequency(self) -> _builtins.str:
        """
        The frequency of Append Only File (AOF) backups.
        """
        return pulumi.get(self, "persistence_append_only_file_backup_frequency")

    @_builtins.property
    @pulumi.getter(name="persistenceRedisDatabaseBackupFrequency")
    def persistence_redis_database_backup_frequency(self) -> _builtins.str:
        """
        The frequency of Redis Database (RDB) backups.
        """
        return pulumi.get(self, "persistence_redis_database_backup_frequency")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        The TCP port of the database endpoint.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="primaryAccessKey")
    def primary_access_key(self) -> _builtins.str:
        """
        The Primary Access Key for the Managed Redis Database instance.
        """
        return pulumi.get(self, "primary_access_key")

    @_builtins.property
    @pulumi.getter(name="secondaryAccessKey")
    def secondary_access_key(self) -> _builtins.str:
        """
        The Secondary Access Key for the Managed Redis Database instance.
        """
        return pulumi.get(self, "secondary_access_key")


@pulumi.output_type
class GetDefaultDatabaseModuleResult(dict):
    def __init__(__self__, *,
                 args: _builtins.str,
                 name: _builtins.str,
                 version: _builtins.str):
        """
        :param _builtins.str args: The configuration options for the module.
        :param _builtins.str name: The name of the Managed Redis instance.
        :param _builtins.str version: The version of the module.
        """
        pulumi.set(__self__, "args", args)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def args(self) -> _builtins.str:
        """
        The configuration options for the module.
        """
        return pulumi.get(self, "args")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the Managed Redis instance.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        """
        The version of the module.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetIdentityResult(dict):
    def __init__(__self__, *,
                 identity_ids: Sequence[_builtins.str],
                 principal_id: _builtins.str,
                 tenant_id: _builtins.str,
                 type: _builtins.str):
        """
        :param Sequence[_builtins.str] identity_ids: A list of User Assigned Managed Identity IDs assigned to the Managed Redis instance.
        :param _builtins.str principal_id: The Principal ID of the System Assigned Managed Service Identity that is configured on the Managed Redis instance.
        :param _builtins.str tenant_id: The Tenant ID of the System Assigned Managed Service Identity that is configured on the Managed Redis instance.
        :param _builtins.str type: The type of Managed Service Identity configured on the Managed Redis instance.
        """
        pulumi.set(__self__, "identity_ids", identity_ids)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "tenant_id", tenant_id)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Sequence[_builtins.str]:
        """
        A list of User Assigned Managed Identity IDs assigned to the Managed Redis instance.
        """
        return pulumi.get(self, "identity_ids")

    @_builtins.property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> _builtins.str:
        """
        The Principal ID of the System Assigned Managed Service Identity that is configured on the Managed Redis instance.
        """
        return pulumi.get(self, "principal_id")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> _builtins.str:
        """
        The Tenant ID of the System Assigned Managed Service Identity that is configured on the Managed Redis instance.
        """
        return pulumi.get(self, "tenant_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of Managed Service Identity configured on the Managed Redis instance.
        """
        return pulumi.get(self, "type")


